@@ -1,5 +1,6 @@
 import socket
 import time
+from typing import Union
 
 import usb
 
@@ -64,3 +65,17 @@ def find_all():
         ]
     ]
     return [find(raw_device=device) for device in solo_devices]
+
+
+def device_path_to_str(path: Union[bytes, str]) -> str:
+    """
+    Converts a device path as returned by the fido2 library to a string.
+
+    Typically, the path already is a string.  Only on Windows, a bytes object
+    using an ANSI encoding is used instead.  We use the ISO 8859-1 encoding to
+    decode the string which should work for all systems.
+    """
+    if isinstance(path, bytes):
+        return path.decode("iso-8859-1", errors="ignore")
+    else:
+        return path
